# ClopHfit #

This README would normally document whatever steps are necessary to get your application up and running.

### What is this repository for? ###

* Cli for fitting macromolecule pH titration or binding assays data e.g. fluorescence spectra.
* Version 0.1.0
* [Learn Markdown](https://bitbucket.org/tutorials/markdowndemo)

### How do I get set up? ###

* Summary of set up
* Configuration
* Dependencies
* Database configuration
* How to run tests
* Deployment instructions

### Contribution guidelines ###

* Writing tests
* Code review
* Other guidelines

### Who do I talk to? ###

* Repo owner or admin
* Other community or team contact
